@@ -45,23 +45,14 @@ void DayNavigatorWidget::setDates(const QDate &aStartDate, const QDate &aEndDate
 
     mStartDate = aStartDate;
     mEndDate = aEndDate;
-    mCurDate = aStartDate;
+    if (!mCurDate.isValid()) mCurDate = mStartDate;
+    // if mCurDate is out of range, set it to mstartDate
+    else if (mCurDate < mStartDate || mCurDate > mEndDate) mCurDate = mStartDate;
 
-    // QRect rect = mFontMetrics->boundingRect(mCurDate.toString("MMM dd yyyy"));
-
-    if(mStartDate==mEndDate) // only one day conference
-    {
-        prevDayButton->setDisabled(true);
-        nextDayButton->setDisabled(true);
-        emit(dateChanged(mCurDate));
-    }
-    else
-    {
-        // at least 2-days conference
-        prevDayButton->setDisabled(true);
-        nextDayButton->setDisabled(false);
-        emit(dateChanged(mCurDate));
-    }
+    prevDayButton->setDisabled(mCurDate == mStartDate);
+    nextDayButton->setDisabled(mCurDate == mEndDate);
+    emit(dateChanged(mCurDate));
+    this->update();
 }
 
 void DayNavigatorWidget::configureNavigation()
